summaryrefslogtreecommitdiff
path: root/noncore/settings/networksettings/interfaces/interface.cpp
Side-by-side diff
Diffstat (limited to 'noncore/settings/networksettings/interfaces/interface.cpp') (more/less context) (show whitespace changes)
-rw-r--r--noncore/settings/networksettings/interfaces/interface.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/noncore/settings/networksettings/interfaces/interface.cpp b/noncore/settings/networksettings/interfaces/interface.cpp
index 69b55d1..b00b899 100644
--- a/noncore/settings/networksettings/interfaces/interface.cpp
+++ b/noncore/settings/networksettings/interfaces/interface.cpp
@@ -76,3 +76,3 @@ void Interface::start(){
int ret = system(QString("%1 %2 up").arg(IFCONFIG).arg(this->name()).latin1());
// See if it was successfull...
if(ret != 0){
@@ -84,3 +84,3 @@ void Interface::start(){
refresh();
- emit (updateMessage("Start successfull"));
+ emit (updateMessage("Start successful"));
}
@@ -105,3 +105,3 @@ void Interface::stop(){
refresh();
- emit (updateMessage("Stop successfull"));
+ emit (updateMessage("Stop successful"));
}
@@ -119,3 +119,3 @@ void Interface::restart(){
* First call ifconfig, then check the dhcp-info file
* @return bool true if successfull.
*/
@@ -76,3 +76,3 @@ void Interface::start(){
int ret = system(QString("%1 %2 up").arg(IFCONFIG).arg(this->name()).latin1());
- // See if it was successfull...
+ // See if it was successful...
if(ret != 0){
@@ -119,3 +119,3 @@ void Interface::restart(){
* First call ifconfig, then check the dhcp-info file
- * @return bool true if successfull.
+ * @return bool true if successful.
*/